#include <cstring>
#include <iostream>
#include <string>

using namespace std;

typedef long long ll;

const int MAXN = 3010;
const int MOD = 1000000007;

inline int add(int a, int b) { return (a+b < MOD) ? a+b : a+b-MOD; }
inline int sub(int a, int b) { return (a-b >= 0) ? a-b : a-b+MOD; }
inline int mul(int a, int b) { return (ll)a * b % MOD; }

namespace solver {
  string s;
  int n;
  int pot10[MAXN];

  // palin[l][r] je true ako substring u intervalu [l, r) palindrom
  bool palin[MAXN][MAXN];

  // broj nacina na koji mogu odabrati palindrom u nekom intervalu u slucaju
  // da moram paziti na rub
  // dodatno, zadnji flag mi kaze smije li palindrom zapoceti s 0 ili ne
  // npr. ako je rub na nekom intervalu "12324", tada imam 24 nacina ako ne
  // ne smijem zapoceti s 0 (10001, 10101, 10201, ..., 12221, 12321) i 124
  // nacina ako smijem zapoceti s 0 (00000, 00100, 00200, ... 12321)
  int g[MAXN][MAXN][2];
  
  // memoizacija
  // 1. trenutna duljina
  // 2. moram li paziti na rub?
  // 3. moram li paziti da ne smijem zapoceti s 0?
  int dp[MAXN][2][2];

  void init() {
    memset(palin, 0, sizeof palin);
    memset(g, 0, sizeof g);
    memset(dp, -1, sizeof dp);
    n = (int)s.size();
    pot10[0] = 1;
    for (int i = 1; i < MAXN; ++i)
      pot10[i] = mul(pot10[i-1], 10);
    for (int i = 0; i < n; ++i) {
      for (int d = 0; d <= 1; ++d)
        for (int j = 0; i+j < n && i-j-d >= 0 && s[i-j-d] == s[i+j]; ++j)
          palin[i-j-d][i+j+1] = true;
    }
    for (int i = 0; i < n; ++i) {
      for (int d = 0; d <= 1; ++d) {
        int curr = 0;
        int carry = 1;
        for (int j = 0; i+j < n && i-j-d >= 0; ++j) {
          if (s[i-j-d] > s[i+j] && carry == 1) carry = 0;
          if (s[i-j-d] < s[i+j] && carry == 1) carry = 2;
          curr = add(curr, mul(s[i-j-d] - '0', pot10[j]));
          g[i-j-d][i+j+1][0] = add(curr, (carry > 0) ? 1 : 0);
          if (s[i-j-d] != '0')
            g[i-j-d][i+j+1][1] = sub(g[i-j-d][i+j+1][0], pot10[j]);
        }
      }
    }
  }

  // izracunava f(0) + f(1) + .. + f(s)
  // b - moram li paziti na rub?
  // z - moram li paziti da ne smijem zapoceti s nulom?
  int rec(int pos, int b, int z) {
    if (pos == n) return 1;
    int &ret = dp[pos][b][z];
    if (ret != -1) return ret;
    ret = z ? rec(pos+1, 0, 1) : 0;
    for (int i = pos+1; i <= n; ++i) {
      if (!b) {
        // ako ne moram paziti na rub, ovaj broj ce biti oblika 10^x, ili 9*10^(x-1)
        int cnt = mul(10 - z, pot10[(i-pos-1) / 2]);
        // jednom kada ne moram vise paziti na rub, tada u sljedecem intervalu koji
        // uzimam i dalje ne moram paziti na rub, a i broj smije zapoceti s 0 jer
        // sam vec odredio pocetni interval (jedino pocetni interval ne smije zapoceti s 0)
        ret = add(ret, mul(cnt, rec(i, 0, 0)));
      } else {
        int cnt = g[pos][i][z];
        if (palin[pos][i]) {
          // samo kada pazim na rub u trentnom intervalu, a taj interval je palindrom,
          // tada cu i u sljedecem koraku morati paziti na rub
          cnt = sub(cnt, 1);
          ret = add(ret, add(rec(i, 1, 0), mul(cnt, rec(i, 0, 0))));
        } else {
          ret = add(ret, mul(cnt, rec(i, 0, 0)));
        }
      }
    }
    return ret;
  }

  int run(string w) {
    s = w;
    init();
    return rec(0, 1, 1);
  }
}

string dec(string w) {
  int p = (int)w.size() - 1;
  while (p >= 0 && w[p] == '0') w[p--] = '9';
  w[p]--;
  if (w[0] == '0') w = w.substr(1);
  return w;
}

int main(void) {
  string a, b;
  cin >> a >> b;
  cout << sub(solver::run(b), solver::run(dec(a))) << endl;
  return 0;
}

